@@ -268,7 +268,7 @@ def deploy(args, parser):
                 built_docs = copy_to_tmp(built_docs)
 
         # Reset in case there are modified files that are tracked in the
-        # dpeloy branch.
+        # deploy branch.
         run(['git', 'stash', '--all'])
         checkout_deploy_branch(deploy_branch, canpush=canpush)
 
@@ -295,7 +295,7 @@ def deploy(args, parser):
             print("The docs have not changed. Not updating")
     except BaseException as e:
         DOCTR_COMMAND = ' '.join(map(shlex.quote, sys.argv))
-        print(red("ERROR: The doctr command %r failed: %s" % (DOCTR_COMMAND, e)),
+        print(red("ERROR: The doctr command %r failed: %r" % (DOCTR_COMMAND, e)),
             file=sys.stderr)
         raise
     finally:
@@ -416,10 +416,10 @@ def configure(args, parser):
           - set -e
           - # Command to build your docs
           - pip install doctr
-          - doctr deploy{options} <target-directory>
+          - doctr deploy {options} <target-directory>
 
         env:
-          global:`
+          global:
             - secure: "{encrypted_variable}"
 
     """.format(options=options, N=N, encrypted_variable=encrypted_variable.decode('utf-8'))))
